"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MissingAttachmentException = exports.AttachmentRegistry = void 0;
class AttachmentRegistry {
    constructor() {
        this.attachments = new Map();
    }
    static createKey() {
        return {
            id: Symbol(),
            marker: 0,
        };
    }
    putAttachment(key, value) {
        this.attachments.set(key.id, value);
    }
    deleteAttachment(key) {
        this.attachments.delete(key.id);
    }
    getAttachment(key) {
        return this.attachments.get(key.id);
    }
    getAttachmentAssert(key) {
        if (!this.hasAttachment(key)) {
            throw new MissingAttachmentException();
        }
        return this.attachments.get(key.id);
    }
    hasAttachment(key) {
        return this.attachments.has(key.id);
    }
    hasAllAttachments(keys) {
        const size = keys.length;
        for (let i = 0; i < size; i++) {
            if (!this.attachments.has(keys[i].id)) {
                return false;
            }
        }
        return true;
    }
    hasAnyAttachments(keys) {
        const size = keys.length;
        for (let i = 0; i < size; i++) {
            if (this.attachments.has(keys[i].id)) {
                return true;
            }
        }
        return false;
    }
}
exports.AttachmentRegistry = AttachmentRegistry;
class MissingAttachmentException extends Error {
    constructor() {
        super("Required attachment was missing from registry");
        this.name = 'MissingAttachmentException';
    }
}
exports.MissingAttachmentException = MissingAttachmentException;
