import { Map } from "./util";
import { OpenAPIV3 } from "openapi-types";
import { ApiContext } from "./context";
import { AttachmentKey } from "./attachment-registry";
export declare type HttpMethod = typeof HttpMethods[number];
export declare type HttpMethodLowercase = typeof HttpMethodsLowercase[number];
export declare const HttpMethodsLowercase: readonly ["post", "put", "patch", "delete", "get", "head", "options"];
export declare const HttpMethods: readonly ["POST", "PUT", "PATCH", "DELETE", "GET", "HEAD", "OPTIONS"];
export declare function lowercaseHttpMethod(method: HttpMethod): HttpMethodLowercase;
export declare function uppercaseHttpMethod(method: HttpMethodLowercase): HttpMethod;
export interface ApiExchange {
    headers: Map<any>;
    body: any;
}
export declare const VALORY_METADATA_VAR = "VALORY_METADATA";
export declare const VALORY_DEFAULT_ADAPTOR_VAR = "VALORY_DEFAULT_ADAPTOR";
export declare const LOGGER_VAR = "LOGLEVEL";
export declare const METADATA_VERSION = 2;
export declare const COMPSWAG_VERSION = 2;
export declare const ROUTES_VERSION = 2;
export declare const GLOBAL_ENTRY_KEY = "VALORY_DATA";
export interface ApiResponse extends ApiExchange {
    statusCode: number;
}
export interface ApiRequest extends ApiExchange {
    rawBody: any;
    formData: Map<any>;
    queryParams: Map<any>;
    pathParams: Map<any>;
    path: string;
    method: HttpMethod;
}
export declare type ApiMiddlewareExecutor = (ctx: ApiContext) => Promise<void> | void;
export interface ApiMiddleware {
    readonly handler: ApiMiddlewareExecutor;
    readonly filter?: {
        readonly mustInclude?: AttachmentKey<any>[];
        readonly mustExclude?: AttachmentKey<any>[];
    };
    readonly name: string;
    readonly tags?: OpenAPIV3.TagObject[];
}
export interface ApiAdaptor {
    register(path: string, method: HttpMethod, handler: (ctx: ApiContext) => Promise<ApiContext>): void;
    start(): any;
    shutdown(): void;
}
