"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.lowercaseKeys = exports.arrayPush = exports.memoizeSingle = exports.versionCheck = exports.sha1Buffer = exports.sha1String = exports.isReferenceObject = void 0;
const crypto_1 = require("crypto");
function isReferenceObject(input) {
    return (typeof input.$ref === "string");
}
exports.isReferenceObject = isReferenceObject;
function sha1String(data) {
    return crypto_1.createHash("sha1").update(data).digest("hex");
}
exports.sha1String = sha1String;
function sha1Buffer(data) {
    return crypto_1.createHash("sha1").update(data).digest();
}
exports.sha1Buffer = sha1Buffer;
function versionCheck(title, required, actual) {
    if (required !== actual) {
        throw Error(`${title} version mismatch. required: ${required} actual: ${actual}`);
    }
}
exports.versionCheck = versionCheck;
function memoizeSingle(fn) {
    let cache = null;
    return () => {
        if (cache == null) {
            cache = fn();
        }
        return cache;
    };
}
exports.memoizeSingle = memoizeSingle;
function arrayPush(target, other) {
    if (other == null || other.length === 0) {
        return target;
    }
    const originalTargetLength = target.length;
    const otherLength = other.length;
    target.length = originalTargetLength + otherLength;
    for (let i = 0; i < otherLength; i++) {
        target[originalTargetLength + i] = other[i];
    }
    return target;
}
exports.arrayPush = arrayPush;
function lowercaseKeys(obj) {
    const keys = Object.keys(obj);
    const n = keys.length;
    for (let i = 0; i < n; i++) {
        const key = keys[i];
        const val = obj[key];
        delete obj[key];
        obj[key.toLowerCase()] = val;
    }
    return obj;
}
exports.lowercaseKeys = lowercaseKeys;
