"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Endpoint = void 0;
const async_series_1 = require("../lib/async-series");
const attachment_registry_1 = require("../lib/common/attachment-registry");
const request_validator_1 = require("./middleware/request-validator");
const util_1 = require("../lib/common/util");
const NOOP_HOOK = (ctx, executor) => executor.execute(ctx);
class Endpoint {
    constructor(valory, path, method) {
        this.valory = valory;
        this.path = path;
        this.method = method;
        this.middleware = [];
        this.logger = valory.logger.child({ path, method });
        this.addDefaultPreMiddleware();
    }
    registerEndpoint() {
        this.valory.adaptor.register(this.path, this.method, this.handleRequest.bind(this));
    }
    buildExecutor() {
        this.executor = new async_series_1.AsyncSeries(this.middleware, (arg, exec, i) => {
            if (exec.filter) {
                if (exec.filter.mustExclude) {
                    if (arg.attachments.hasAnyAttachments(exec.filter.mustExclude))
                        return false;
                }
                if (exec.filter.mustInclude) {
                    if (!arg.attachments.hasAllAttachments(exec.filter.mustInclude))
                        return false;
                }
            }
            const handlerLogger = arg.attachments.getAttachment(Endpoint.RequestLoggerKey).child({ middleware: this.middleware[i].name });
            arg.attachments.putAttachment(Endpoint.HandlerLoggerKey, handlerLogger);
            return true;
        }, (arg, err, i) => {
            arg.attachments.putAttachment(Endpoint.ExceptionKey, err);
        });
    }
    async handleRequest(ctx) {
        const requestLogger = this.logger.child({ requestId: ctx.requestId });
        ctx.attachments.putAttachment(Endpoint.RequestLoggerKey, requestLogger);
        await this.executor.execute(ctx);
        return ctx;
    }
    appendMiddleware(middleware) {
        return this.aM(middleware);
    }
    aM(middleware) {
        this.middleware.push(middleware);
        return this;
    }
    appendMiddlewareList(middlewares) {
        return this.aML(middlewares);
    }
    aML(middlewares) {
        this.middleware = util_1.arrayPush(this.middleware, middlewares);
        return this;
    }
    addDefaultPreMiddleware() {
        this.appendMiddleware(new request_validator_1.RequestValidator(this.valory, this.path, this.method));
        this.appendMiddlewareList(this.valory.beforeAllMiddleware);
    }
    addDefaultPostMiddleware() {
        this.appendMiddlewareList(this.valory.afterAllMiddleware);
    }
    done() {
        this.addDefaultPostMiddleware();
        this.registerEndpoint();
        this.buildExecutor();
    }
}
exports.Endpoint = Endpoint;
Endpoint.ExceptionKey = attachment_registry_1.AttachmentRegistry.createKey();
Endpoint.RequestLoggerKey = attachment_registry_1.AttachmentRegistry.createKey();
Endpoint.HandlerLoggerKey = attachment_registry_1.AttachmentRegistry.createKey();
