"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Valory = void 0;
const headers_1 = require("../lib/common/headers");
const endpoint_1 = require("./endpoint");
const P = require("pino");
const global_data_load_1 = require("../lib/global-data-load");
class Valory {
    constructor(args) {
        if (Valory.instance != null) {
            throw new Error("Valory instance has already been created");
        }
        if (Valory.directInstantiation) {
            throw new Error("Valory should not be directly instantiated");
        }
        Valory.instance = this;
        const { adaptor, baseLogger, afterAllMiddleware, beforeAllMiddleware } = args;
        this.adaptor = Valory.resolveAdaptor(adaptor);
        this.afterAllMiddleware = afterAllMiddleware;
        this.beforeAllMiddleware = beforeAllMiddleware;
        this.logger = baseLogger || P();
        this.logger.info("Starting Valory");
        this.globalData = global_data_load_1.loadGlobalData();
        this.registerGeneratedRoutes(this.globalData.routes);
    }
    static createInstance(args) {
        Valory.directInstantiation = false;
        return new Valory(args);
    }
    static getInstance() {
        if (Valory.instance == null) {
            throw new Error("Valory instance has not yet been created");
        }
        return Valory.instance;
    }
    static resolveAdaptor(provided) {
        const defaultAdaptorPath = process.env[headers_1.VALORY_DEFAULT_ADAPTOR_VAR];
        if (defaultAdaptorPath == null) {
            return provided;
        }
        const defaultAdaptor = require(defaultAdaptorPath).DefaultAdaptor;
        return new defaultAdaptor(8080);
    }
    endpoint(path, method) {
        return new endpoint_1.Endpoint(this, path, method);
    }
    start() {
        this.logger.info("Startup Complete");
        return this.adaptor.start();
    }
    shutdown() {
        return this.adaptor.shutdown();
    }
    registerGeneratedRoutes(routes) {
        routes.register(this);
    }
}
exports.Valory = Valory;
Valory.directInstantiation = true;
